==> config-api-3.1-sources.jar: org/glassfish/config/support/ServerReaderFilter.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2008-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.config.support;

import java.io.*;
import java.net.*;
import java.util.*;
import java.util.logging.*;
import javax.xml.stream.*;
import org.jvnet.hk2.component.Habitat;

/**
 * Instances and DAS' are quite different
 * @author Byron Nevins
 */
abstract class ServerReaderFilter extends XMLStreamReaderFilter {
    ServerReaderFilter(Habitat theHabitat, URL theDomainXml,
            XMLInputFactory theXif) throws XMLStreamException {

        try {
            domainXml = theDomainXml;
            xif = theXif;
            stream = domainXml.openStream();
            habitat =  theHabitat;
            setParent(xif.createXMLStreamReader(domainXml.toExternalForm(), stream));
        }
        catch(IOException e) {
            throw new XMLStreamException(e);
        }
    }

    @Override
    final public void close() throws XMLStreamException {
        try {
            super.close();
            stream.close();
        }
        catch (Exception e) {
            throw new XMLStreamException(e);
        }
    }

    /**
     * Report on whether parsing was a success or not.  If there is a missing config
     * for a server just return a String message.
     * @return a String error message if there was an error else return null for all-ok
     */
    abstract String configWasFound();

    final URL domainXml;
    final XMLInputFactory xif;
    final InputStream stream;
    final Habitat habitat;
}

==> config-api-3.1.1-b07-sources.jar: org/glassfish/config/support/ServerReaderFilter.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2008-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.config.support;

import java.io.*;
import java.net.*;
import java.util.*;
import java.util.logging.*;
import javax.xml.stream.*;

/**
 * Instances and DAS' are quite different
 * @author Byron Nevins
 */
abstract class ServerReaderFilter extends XMLStreamReaderFilter {
    ServerReaderFilter(URL theDomainXml,
            XMLInputFactory theXif) throws XMLStreamException {

        try {
            domainXml = theDomainXml;
            xif = theXif;
            stream = domainXml.openStream();
            setParent(xif.createXMLStreamReader(domainXml.toExternalForm(), stream));
        }
        catch(IOException e) {
            throw new XMLStreamException(e);
        }
    }

    @Override
    final public void close() throws XMLStreamException {
        try {
            super.close();
            stream.close();
        }
        catch (Exception e) {
            throw new XMLStreamException(e);
        }
    }

    /**
     * Report on whether parsing was a success or not.  If there is a missing config
     * for a server just return a String message.
     * @return a String error message if there was an error else return null for all-ok
     */
    abstract String configWasFound();

    final URL domainXml;
    final XMLInputFactory xif;
    final InputStream stream;
}
